@@ -18,7 +18,7 @@ use Mac::Resources;
 @EXPORT_OK   = qw(read_alias make_alias);
 %EXPORT_TAGS = ( all => [ @EXPORT_OK ] );
 
-$VERSION = '0.10_02';
+$VERSION = '0.11';
 
 =head1 NAME
 
@@ -110,13 +110,9 @@ sub make_alias
 
 =head1 SOURCE AVAILABILITY
 
-This source is part of a SourceForge project which always has the
-latest sources in SVN, as well as all of the previous releases.
+This source is in Github
 
-	http://sourceforge.net/projects/brian-d-foy/
-
-If, for some reason, I disappear from the world, one of the other
-members of the project can shepherd this module appropriately.
+	git://github.com/briandfoy/macosx-alias.git
 
 =head1 AUTHORS
 
@@ -126,7 +122,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2007, brian d foy, All Rights Reserved.
+Copyright (c) 2007-2008, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
